@@ -45,7 +45,14 @@ def make_setup(args):
         input_path = os.path.abspath(os.curdir)
 
 
-    f = open(input_path + "\\setup.sh", "w")
+    appname = args['<appname>']
+    if appname is None:
+        appname = input("Looks like you forgot to put your appname, please type it here \n")
+
+    if not appname.endswith(".py"):
+        appname = appname + ".py"
+
+    f = open(input_path + "\\setup_" + appname + ".sh", "w")
 
     email = args['<email>']
     if email is None:
@@ -80,7 +87,7 @@ def make_procfile(args):
     if not appname.endswith(".py"):
         appname = appname + ".py"
     
-    f.write("web: sh setup.sh && streamlit run " + appname)
+    f.write("web: sh setup_" + appname + ".sh && streamlit run " + appname)
     f.close()
 
 
